<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Jose Luis Sanches <jose.reis.sanches@gmail.com>
 * @author Gustavo B. Schenkel <gustavo.schenkel@gmail.com>
 * @author Paulo <pschopf@gmail.com>
 * @author Mario AlexandTeixeira dos Santos <masterofclan@gmail.com>
 * @author Maykon Oliveira <maykonoliveira850@gmail.com>
 * @author José Vieira <jmsv63@gmail.com>
 * @author José Carlos Monteiro <jose.c.monteiro@netcabo.pt>
 * @author José Monteiro <Jose.Monteiro@DoWeDo-IT.com>
 * @author Enrico Nicoletto <liverig@gmail.com>
 * @author Fil <fil@meteopt.com>
 * @author André Neves <drakferion@gmail.com>
 * @author José Campos <zecarlosdecampos@gmail.com>
 * @author Murilo <muriloricci@hotmail.com>
 * @author Paulo Silva <paulotsilva@yahoo.com>
 * @author Guido Salatino <guidorafael23@gmail.com>
 * @author Romulo Pereira <romuloccomp@gmail.com>
 * @author Paulo Carmino <contato@paulocarmino.com>
 * @author Alfredo Silva <alfredo.silva@sky.com>
 * @author Guilherme Sá <guilherme.sa@hotmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Editar esta página';
$lang['btn_source']            = 'Mostrar página fonte ';
$lang['btn_show']              = 'Mostrar página';
$lang['btn_create']            = 'Criar esta página';
$lang['btn_search']            = 'Pesquisar';
$lang['btn_save']              = 'Salvar';
$lang['btn_preview']           = 'Pré-visualizar';
$lang['btn_top']               = 'Voltar ao topo';
$lang['btn_newer']             = '<< mais recente';
$lang['btn_older']             = 'menos recente >>';
$lang['btn_revs']              = 'Revisões antigas';
$lang['btn_recent']            = 'Alterações Recentes';
$lang['btn_upload']            = 'Enviar';
$lang['btn_cancel']            = 'Cancelar';
$lang['btn_index']             = 'Índice';
$lang['btn_secedit']           = 'Editar';
$lang['btn_login']             = 'Iniciar sessão';
$lang['btn_logout']            = 'Terminar sessão';
$lang['btn_admin']             = 'Administrar';
$lang['btn_update']            = 'Atualizar';
$lang['btn_delete']            = 'Excluir';
$lang['btn_back']              = 'Voltar';
$lang['btn_backlink']          = 'Backlinks';
$lang['btn_subscribe']         = 'Gerir Subscrições';
$lang['btn_profile']           = 'Atualizar Perfil';
$lang['btn_reset']             = 'Redefinir';
$lang['btn_resendpwd']         = 'Definir nova senha';
$lang['btn_draft']             = 'Editar rascunho';
$lang['btn_recover']           = 'Recuperar rascunho';
$lang['btn_draftdel']          = 'Apagar rascunho';
$lang['btn_revert']            = 'Restaurar';
$lang['btn_register']          = 'Registar';
$lang['btn_apply']             = 'Aplicar';
$lang['btn_media']             = 'Gestor de Media';
$lang['btn_deleteuser']        = 'Remover a Minha Conta';
$lang['btn_img_backto']        = 'De volta a %s';
$lang['btn_mediaManager']      = 'Ver no gestor de media';
$lang['loggedinas']            = 'Está em sessão como:';
$lang['user']                  = 'Utilizador';
$lang['pass']                  = 'Senha';
$lang['newpass']               = 'Nova senha';
$lang['oldpass']               = 'Confirme senha atual';
$lang['passchk']               = 'mais uma vez';
$lang['remember']              = 'Lembrar?';
$lang['fullname']              = 'Nome completo';
$lang['email']                 = 'E-mail';
$lang['profile']               = 'Perfil do Utilizador';
$lang['badlogin']              = 'Utilizador ou ou senha inválida.';
$lang['badpassconfirm']        = 'Infelizmente a senha não é a correta';
$lang['minoredit']             = 'Alterações Menores';
$lang['draftdate']             = 'Rascunho automaticamente gravado em';
$lang['nosecedit']             = 'A página foi modificada. Como a informação da seção estava desatualizada, foi carregada a página inteira.';
$lang['searchcreatepage']      = 'Se não encontrou o que procurava, pode criar uma nova página com o nome %s.';
$lang['search_fullresults']    = 'O que foi encontrado nos textos';
$lang['js']['search_toggle_tools'] = 'Mudar Ferramenta de Pesquisa';
$lang['js']['willexpire']      = 'O bloqueio de edição para este documento irá expirar em um minuto.\nPara evitar conflitos use o botão prever para reiniciar o temporizador de bloqueio.';
$lang['js']['notsavedyet']     = 'Alterações não salvas serão perdidas.';
$lang['js']['searchmedia']     = 'Procurar por arquivos';
$lang['js']['keepopen']        = 'Mantenha a janela aberta durante a selecção';
$lang['js']['hidedetails']     = 'Esconder Detalhes';
$lang['js']['mediatitle']      = 'Configurações de link';
$lang['js']['mediadisplay']    = 'Tipo de link';
$lang['js']['mediaalign']      = 'Alinhamento';
$lang['js']['mediasize']       = 'Tamanho da imagem';
$lang['js']['mediatarget']     = 'Alvo do link';
$lang['js']['mediaclose']      = 'Fechar';
$lang['js']['mediainsert']     = 'Inserir';
$lang['js']['mediadisplayimg'] = 'Mostrar a imagem.';
$lang['js']['mediadisplaylnk'] = 'Mostrar apenas o link.';
$lang['js']['mediasmall']      = 'Versão pequena';
$lang['js']['mediamedium']     = 'Versão média';
$lang['js']['medialarge']      = 'Versão grande';
$lang['js']['mediaoriginal']   = 'Versão original';
$lang['js']['medialnk']        = 'Link para a página de detalhe';
$lang['js']['mediadirect']     = 'Link direto para o original';
$lang['js']['medianolnk']      = 'Nenhuma link';
$lang['js']['medianolink']     = 'Não linkar à imagem';
$lang['js']['medialeft']       = 'Alinhar a imagem à esquerda.';
$lang['js']['mediaright']      = 'Alinhar a imagem à direita.';
$lang['js']['mediacenter']     = 'Alinhar a imagem ao centro.';
$lang['js']['medianoalign']    = 'Não usar nenhum alinhamento.';
$lang['js']['nosmblinks']      = 'Linkar a pasta Windows compartilhada apenas funciona com o Microsoft Internet Explorer.\nPode no entanto copiar e colar o link.';
$lang['js']['linkwiz']         = 'Assistente de Criação de Link';
$lang['js']['linkto']          = 'Link para:';
$lang['js']['del_confirm']     = 'Remover o(s) item(s) selecionados?';
$lang['js']['restore_confirm'] = 'Restaurar esta versão?';
$lang['js']['media_diff']      = 'Ver diferenças:';
$lang['js']['media_diff_both'] = 'Lado a Lado';
$lang['js']['media_diff_opacity'] = 'Sobreposição';
$lang['js']['media_diff_portions'] = 'Slider';
$lang['js']['media_select']    = 'Selecione arquivos…';
$lang['js']['media_upload_btn'] = 'Enviar';
$lang['js']['media_done_btn']  = 'Feito';
$lang['js']['media_drop']      = 'Largue arquivo aqui para enviar';
$lang['js']['media_cancel']    = 'excluir';
$lang['js']['media_overwrt']   = 'Escrever por cima de arquivos existentes';
$lang['js']['data_insecure']   = 'AVISO: Parece que o seu diretório de dados não está devidamente protegido. Por favor leia sobre <a href="https://www.dokuwiki.org/security#web_access_security">Segurança de acesso à web em DokuWiki</a>.';
$lang['search_exact_match']    = 'Correspondência exata';
$lang['search_starts_with']    = 'Começa por';
$lang['search_ends_with']      = 'Termina em';
$lang['search_contains']       = 'Contém';
$lang['search_custom_match']   = 'Personalizado';
$lang['search_any_ns']         = 'Qualquer local';
$lang['search_any_time']       = 'Em qualquer momento';
$lang['search_past_7_days']    = 'Semana passada';
$lang['search_past_month']     = 'Mês passado';
$lang['search_past_year']      = 'Ano passado';
$lang['search_sort_by_hits']   = 'Ordenar por ocorrência';
$lang['search_sort_by_mtime']  = 'Ordenar pela última alteração';
$lang['regmissing']            = 'Por favor, preencha todos os campos.';
$lang['reguexists']            = 'Este utilizador já está inscrito. Por favor escolha outro nome de utilizador.';
$lang['regsuccess']            = 'O utilizador foi criado e a senha foi enviada para o endereço de correio eletrónico usado na inscrição.';
$lang['regsuccess2']           = 'O utilizador foi criado.';
$lang['regfail']               = 'O utilizador não pode ser criado.';
$lang['regmailfail']           = 'Houve um erro no envio da senha por e-mail. Por favor, contacte o administrador!';
$lang['regbadmail']            = 'O endereço de correio eletrónico é inválido. Se o endereço está correto e isto é um erro, contacte o administrador!';
$lang['regbadpass']            = 'As duas senhas não são idênticas, por favor tente de novo.';
$lang['regpwmail']             = 'A sua senha DokuWiki';
$lang['reghere']               = 'Ainda não tem uma conta? Registe-se';
$lang['profna']                = 'Este Wiki não suporta modificações nos perfis';
$lang['profnochange']          = 'Nenhuma alteração, nada a fazer.';
$lang['profnoempty']           = 'Não são permitidos nomes ou e-mails em branco.';
$lang['profchanged']           = 'Perfil do utilizador atualizado com sucesso.';
$lang['profnodelete']          = 'Este wiki não suporta remoção de utilizadores';
$lang['profdeleteuser']        = 'Apagar Conta';
$lang['profdeleted']           = 'A sua conta de utilizador foi removida deste wiki';
$lang['profconfdelete']        = 'Quero remover a minha conta deste wiki. <br/> Esta ação não pode ser desfeita.';
$lang['profconfdeletemissing'] = 'A caixa de confirmação não foi marcada';
$lang['proffail']              = 'O perfil do utilizador não foi atualizado.';
$lang['pwdforget']             = 'Esqueceu a sua senha? Peça uma nova';
$lang['resendna']              = 'Este wiki não suporta reenvio de senhas.';
$lang['resendpwd']             = 'Definir nova senha para';
$lang['resendpwdmissing']      = 'É preciso preencher todos os campos.';
$lang['resendpwdnouser']       = 'Não foi possível encontrar este utilizador.';
$lang['resendpwdbadauth']      = 'O código de autenticação não é válido. Por favor, assegure-se de que o link de confirmação está completo.';
$lang['resendpwdconfirm']      = 'O link de confirmação foi enviado por e-mail.';
$lang['resendpwdsuccess']      = 'A nova senha foi enviada por e-mail.';
$lang['license']               = 'Excepto menção em contrário, o conteúdo neste wiki está sob a seguinte licença:';
$lang['licenseok']             = 'Nota: Ao editar esta página aceita disponibilizar o seu conteúdo sob a seguinte licença:';
$lang['searchmedia']           = 'Procurar nome de arquivo:';
$lang['searchmedia_in']        = 'Procurar em %s';
$lang['txt_upload']            = 'Escolha arquivo a carregar:';
$lang['txt_filename']          = 'Carregar como (opcional):';
$lang['txt_overwrt']           = 'Sobrescrever arquivo';
$lang['maxuploadsize']         = 'Enviar %s max. por arquivo.';
$lang['allowedmime']           = 'Lista de extensões de arquivo permitidas';
$lang['lockedby']              = 'Bloqueado por:';
$lang['lockexpire']            = 'Expira em:';
$lang['rssfailed']             = 'Erro ao buscar informação deste feed:';
$lang['nothingfound']          = 'Nada foi encontrado.';
$lang['mediaselect']           = 'Seleção de arquivos';
$lang['uploadsucc']            = 'Enviado com sucesso';
$lang['uploadfail']            = 'O envio falhou. Talvez por não ter permissões?';
$lang['uploadwrong']           = 'Envio negado. Esta extensão de arquivo é proibida!';
$lang['uploadexist']           = 'O arquivo já existe. Nada foi feito.';
$lang['uploadbadcontent']      = 'O conteúdo do envio não corresponde à extensão %s.';
$lang['uploadspam']            = 'O envio foi bloqueado pela lista negra de spam.';
$lang['uploadxss']             = 'O envio foi bloqueado porque possivelmente contem conteúdo malicioso.';
$lang['uploadsize']            = 'O arquivo enviado é muito grande. (máx. %s)';
$lang['deletesucc']            = 'O arquivo "%s" foi excluído.';
$lang['deletefail']            = 'O arquivo "%s" não pode ser excluído - verifique as permissões.';
$lang['mediainuse']            = 'O arquivo "%s" não foi excluído porque está sendo usado.';
$lang['namespaces']            = 'Namespaces';
$lang['mediafiles']            = 'Arquivos disponíveis em';
$lang['accessdenied']          = 'Não tem permissão para ver esta página.';
$lang['mediausage']            = 'Use a seguinte sintaxe para referenciar este arquivo:';
$lang['mediaview']             = 'Ver arquivo original';
$lang['mediaroot']             = 'root';
$lang['mediaupload']           = 'Enviar arquivos para o grupo atual aqui. Para criar sub-grupos: escrever o nome do sub-grupo seguido de: antes do nome do arquivo no campo "Enviar como".';
$lang['mediaextchange']        = 'Extensão alterada de .%s para .%s!';
$lang['reference']             = 'Referências para';
$lang['ref_inuse']             = 'O arquivo não pode ser removido, porque está sendo usado nestes documentos:';
$lang['ref_hidden']            = 'Algumas referências estão em documentos para os quais não tem permissão para ler';
$lang['hits']                  = 'Resultados';
$lang['quickhits']             = 'Pagenames encontrados';
$lang['toc']                   = 'Tabela de Conteúdos';
$lang['current']               = 'Atual';
$lang['yours']                 = 'Sua versão';
$lang['diff']                  = 'Mostrar diferenças com a versão atual';
$lang['diff2']                 = 'Mostrar diferenças entre versões escolhidas';
$lang['difflink']              = 'Links para esta vista de comparação';
$lang['diff_type']             = 'Ver diferenças:';
$lang['diff_inline']           = 'Embutido';
$lang['diff_side']             = 'Lado a Lado';
$lang['diffprevrev']           = 'Revisão anterior';
$lang['diffnextrev']           = 'Próxima revisão';
$lang['difflastrev']           = 'Última revisão';
$lang['diffbothprevrev']       = 'Ambos os lados da revisão anterior';
$lang['diffbothnextrev']       = 'Ambos os lados da próxima revisão';
$lang['line']                  = 'Linha';
$lang['breadcrumb']            = 'Está em:';
$lang['youarehere']            = 'Está aqui:';
$lang['lastmod']               = 'Última modificação em:';
$lang['by']                    = 'por';
$lang['deleted']               = 'excluído';
$lang['created']               = 'criado';
$lang['restored']              = 'versão anterior restaurada (%s)';
$lang['external_edit']         = 'edição externa';
$lang['summary']               = 'Sumário da edição';
$lang['noflash']               = 'O <a href="http://get.adobe.com/flashplayer">Plugin Adobe Flash</a> é necessário para exibir este conteúdo.';
$lang['download']              = 'Baixar Snippet';
$lang['tools']                 = 'Ferramentas';
$lang['user_tools']            = 'Ferramentas de Utilizador';
$lang['site_tools']            = 'Ferramentas de Site';
$lang['page_tools']            = 'Ferramentas de Página';
$lang['skip_to_content']       = 'ir ao conteúdo';
$lang['sidebar']               = 'Barra Lateral';
$lang['mail_newpage']          = 'documento adicionado:';
$lang['mail_changed']          = 'documento modificado:';
$lang['mail_subscribe_list']   = 'páginas alteradas no namespace:';
$lang['mail_new_user']         = 'Novo utilizador:';
$lang['mail_upload']           = 'Arquivo enviado:';
$lang['changes_type']          = 'Ver alterações de';
$lang['pages_changes']         = 'Páginas';
$lang['media_changes']         = 'Arquivo de media';
$lang['both_changes']          = 'Tanto páginas como arquivos de media';
$lang['qb_bold']               = 'Texto Negrito';
$lang['qb_italic']             = 'Texto Itálico';
$lang['qb_underl']             = 'Texto Sublinhado';
$lang['qb_code']               = 'Texto Monoespaçado';
$lang['qb_strike']             = 'Texto Riscado';
$lang['qb_h1']                 = 'Cabeçalho Nível 1';
$lang['qb_h2']                 = 'Cabeçalho Nível 2';
$lang['qb_h3']                 = 'Cabeçalho Nível 3';
$lang['qb_h4']                 = 'Cabeçalho Nível 4';
$lang['qb_h5']                 = 'Cabeçalho Nível 5';
$lang['qb_h']                  = 'Cabeçalho';
$lang['qb_hs']                 = 'Selecionar Cabeçalho';
$lang['qb_hplus']              = 'Cabeçalho Maior';
$lang['qb_hminus']             = 'Cabeçalho Menor';
$lang['qb_hequal']             = 'Cabeçalho de Nível Semelhante';
$lang['qb_link']               = 'Link Interno';
$lang['qb_extlink']            = 'Link Externo';
$lang['qb_hr']                 = 'Barra Horizontal';
$lang['qb_ol']                 = 'Item numa Lista Ordenada';
$lang['qb_ul']                 = 'Item numa Lista Não Ordenada';
$lang['qb_media']              = 'Incluir imagens e outros arquivos (abre numa nova página)';
$lang['qb_sig']                = 'Inserir Assinatura';
$lang['qb_smileys']            = 'Smileys';
$lang['qb_chars']              = 'Caracteres Especiais';
$lang['upperns']               = 'Ir para o namespace superior';
$lang['metaedit']              = 'Editar Metadata';
$lang['metasaveerr']           = 'Erro na escrita de Metadata';
$lang['metasaveok']            = 'Metadata salva';
$lang['img_title']             = 'Título:';
$lang['img_caption']           = 'Legenda:';
$lang['img_date']              = 'Data:';
$lang['img_fname']             = 'Arquivo:';
$lang['img_fsize']             = 'Tamanho:';
$lang['img_artist']            = 'Fotógrafo:';
$lang['img_copyr']             = 'Copyright:';
$lang['img_format']            = 'Formato:';
$lang['img_camera']            = 'Câmara:';
$lang['img_keywords']          = 'Palavras-Chave:';
$lang['img_width']             = 'Largura:';
$lang['img_height']            = 'Altura:';
$lang['subscr_subscribe_success'] = 'Adicionado %s à lista de subscrição para %s';
$lang['subscr_subscribe_error'] = 'Erro ao adicionar %s à lista de subscrição para %s';
$lang['subscr_subscribe_noaddress'] = 'Não existe endereço algum associado com o seu nome de utilizador, não pode ser adicionado à lista de subscrição';
$lang['subscr_unsubscribe_success'] = 'Removido %s da lista de subscrição para %s';
$lang['subscr_unsubscribe_error'] = 'Erro ao remover %s da lista de subscrição para %s';
$lang['subscr_already_subscribed'] = '%s já está subscrito em %s';
$lang['subscr_not_subscribed'] = '%s não está subscrito em %s';
$lang['subscr_m_not_subscribed'] = 'Não está subscrito à página ou namespace corrente.';
$lang['subscr_m_new_header']   = 'Adicionar subscrição';
$lang['subscr_m_current_header'] = 'Subscrições atuais';
$lang['subscr_m_unsubscribe']  = 'Des-subscrever';
$lang['subscr_m_subscribe']    = 'Subscrever';
$lang['subscr_m_receive']      = 'Receber';
$lang['subscr_style_every']    = 'e-mail em toda alteração';
$lang['subscr_style_digest']   = '"digest email" de alterações em cada página (cada %.2f dias)';
$lang['subscr_style_list']     = 'lista de páginas alteradas desde o último e-mail (cada %.2f dias)';
$lang['authtempfail']          = 'Autenticação temporariamente indisponível. Se a situação persistir, informe o Administrador do Wiki.';
$lang['i_chooselang']          = 'Escolha o idioma';
$lang['i_installer']           = 'Instalador do DokuWiki';
$lang['i_wikiname']            = 'Nome Wiki';
$lang['i_enableacl']           = 'Ativar ACL (recomendado)';
$lang['i_superuser']           = 'Superutilizador';
$lang['i_problems']            = 'O instalador encontrou alguns problemas, indicados abaixo. Não pode continuar até que sejam corrigidos.';
$lang['i_modified']            = 'Por razões de segurança, este script só funciona em novas e não-modificadas instalações do Dokuwiki. Deve re-extrair os arquivos do pacote que baixou ou então consultar as <a href="https://www.dokuwiki.org/install">instruções de instalação do Dokuwiki</a>';
$lang['i_funcna']              = 'A função PHP <code>%s</code> não está disponível. Talvez o host a tenha desativado por alguma razão?';
$lang['i_disabled']            = 'Isso foi desativado pelo seu provedor.';
$lang['i_funcnmail']           = '<b>Nota:</b> A função mail do PHP não está disponível. %s Se permanecer indisponível, instale o <a href="https://www.dokuwiki.org/plugin:smtp">plugin smtp</a>.';
$lang['i_phpver']              = 'A versão de PHP actual <code>%s</code> é inferior à versão mínima <code>%s</code>. É preciso atualizar a instalação PHP.';
$lang['i_mbfuncoverload']      = 'mbstring.func_overload deve ser desativada no php.ini para executar o DokuWiki.';
$lang['i_urandom']             = 'DokuWiki não pode criar números criptograficamente seguros para cookies. Verifique a configuração open_basedir no php.ini para um acesso <code>/dev/urandom</code> adequado.';
$lang['i_permfail']            = '<code>%s</code> não permite que o DokuWiki escreva nela. É preciso corrigir as permissões desta pasta!';
$lang['i_confexists']          = '<code>%s</code> já existe';
$lang['i_writeerr']            = 'Não foi possível criar <code>%s</code>. É preciso verificar as permissões e criar o arquivo manualmente.';
$lang['i_badhash']             = 'dokuwiki.php não é o original ou não é reconhecido (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - valor ilegal ou vazio';
$lang['i_success']             = 'A instalação e a configuração inicial terminaram. Pode remover o install.php. Aceda ao seu novo <a href="doku.php?id=wiki:welcome">Wiki</a> rodando o DokuWiki.';
$lang['i_failure']             = 'Ocorreram alguns erros durante a escrita nos arquivos de configuração. Poderá ser preciso corrigi-los manualmente antes de poder aceder ao seu novo <a href="doku.php?id=wiki:welcome">Wiki</a> rodando o DokuWiki.';
$lang['i_policy']              = 'Política ACL inicial';
$lang['i_pol0']                = 'Wiki Aberto (ler, escrever e enviar arquivos para todos)';
$lang['i_pol1']                = 'Wiki Público (ler para todos, escrever e enviar arquivos para utilizadores inscritos)';
$lang['i_pol2']                = 'Wiki Fechado (ler, escrever e enviar arquivos somente para utilizadores inscritos)';
$lang['i_allowreg']            = 'Permitir aos utilizadores registarem-se sozinhos';
$lang['i_retry']               = 'Repetir';
$lang['i_license']             = 'Por favor escolha a licença sob a qual quer colocar o seu conteúdo:';
$lang['i_license_none']        = 'Não mostrar nenhuma informação de licença';
$lang['i_pop_field']           = 'Por favor ajude-nos a melhorar a experiência Dokuwiki:';
$lang['i_pop_label']           = 'Uma vez por mês, enviar dados anónimos de uso para os desenvolvedores DokuWiki';
$lang['recent_global']         = 'Está a ver as alterações dentro do namespace <b>%s</b>. Também é possível ver as <a href="%s">modificações recentes no wiki inteiro</a>.';
$lang['years']                 = '%d anos atrás';
$lang['months']                = '%d meses atrás';
$lang['weeks']                 = '%d semanas atrás';
$lang['days']                  = '%d dias atrás';
$lang['hours']                 = '%d horas atrás';
$lang['minutes']               = '%d minutos atrás';
$lang['seconds']               = '%d segundos atrás';
$lang['wordblock']             = 'A sua alteração não foi guardada porque contém texto bloqueado (spam).';
$lang['media_uploadtab']       = 'Enviar';
$lang['media_searchtab']       = 'Procurar';
$lang['media_file']            = 'Arquivo';
$lang['media_viewtab']         = 'Ver';
$lang['media_edittab']         = 'Editar';
$lang['media_historytab']      = 'Histórico';
$lang['media_list_thumbs']     = 'Miniaturas';
$lang['media_list_rows']       = 'Linhas';
$lang['media_sort_name']       = 'Nome';
$lang['media_sort_date']       = 'Data';
$lang['media_namespaces']      = 'Escolha o namespace';
$lang['media_files']           = 'Arquivos em %s';
$lang['media_upload']          = 'Enviar para %s';
$lang['media_search']          = 'Procurar em %s';
$lang['media_view']            = '%s';
$lang['media_viewold']         = '%s em %s';
$lang['media_edit']            = 'Editar %s';
$lang['media_history']         = 'Histórico do %s';
$lang['media_meta_edited']     = 'metadata editada';
$lang['media_perm_read']       = 'Perdão, não tem permissão para ler arquivos.';
$lang['media_perm_upload']     = 'Perdão, não tem permissão para enviar arquivos.';
$lang['media_update']          = 'Enviar nova versão';
$lang['media_restore']         = 'Restaurar esta versão';
$lang['media_acl_warning']     = 'Essa lista pode não estar completa devido a restrições de ACL e páginas ocultas.';
$lang['email_fail']            = 'O mail() PHP está ausente ou desativado. O seguinte e-mail não foi enviado:';
$lang['currentns']             = 'Namespace atual';
$lang['searchresult']          = 'Resultado da Pesquisa';
$lang['plainhtml']             = 'HTML simples';
$lang['wikimarkup']            = 'Markup de Wiki';
$lang['page_nonexist_rev']     = 'Página não existia no %s. Posteriormente, foi criada em <a href="%s">%s</a>.';
$lang['unable_to_parse_date']  = 'Não é possível analisar o parâmetro "%s".';
$lang['email_signature_text']  = 'Este email foi gerado por DokuWiki em
@DOKUWIKIURL@';
